pub struct StCuts {
pub cuts: Vec<Vec<EdgeId>>,
pub partition1s: Vec<Vec<VertexId>>,
}Expand description
All minimal s-t edge cuts of a directed graph, see Graph::all_st_cuts.
Fields
cuts: Vec<Vec<EdgeId>>Every minimal cut, as a list of edge ids.
partition1s: Vec<Vec<VertexId>>For each cut, the vertex set X generating it: the cut consists of
all edges from X to its complement. X contains the source.