pub struct StMinCuts {
pub value: f64,
pub cuts: Vec<Vec<EdgeId>>,
pub partition1s: Vec<Vec<VertexId>>,
}Expand description
All minimum s-t edge cuts of a directed graph, see
Graph::all_st_mincuts.
Fields
value: f64The (common) total capacity of the minimum cuts.
cuts: Vec<Vec<EdgeId>>Every minimum cut, as a list of edge ids.
partition1s: Vec<Vec<VertexId>>For each cut, the vertex set X generating it: the cut consists of
all edges from X to its complement. X contains the source.