pub struct DominatorTree {
pub dom: Vec<Option<VertexId>>,
pub tree: Graph,
pub leftout: Vec<VertexId>,
}Expand description
A dominator tree of a flowgraph, see Graph::dominator_tree.
Fields
dom: Vec<Option<VertexId>>Immediate dominator of each vertex, indexed by vertex id. It is
None for the root itself and for the vertices unreachable from the
root (the latter are also listed in leftout).
tree: GraphThe dominator tree as a directed graph on the same vertex set, with an
edge from idom(w) to w (reversed when mode is
NeighborMode::In); unreachable vertices are isolated.
leftout: Vec<VertexId>Ids of the vertices that are not reachable from the root.
Implementations
Sourceimpl DominatorTree
impl DominatorTree